@@ -1,4 +1,4 @@
-// $Id: dbgmainwnd.cpp,v 1.47 2000/11/05 10:02:16 jsixt Exp $
+// $Id: dbgmainwnd.cpp,v 1.49 2001/07/17 20:31:48 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -147,6 +147,13 @@ DebuggerMainWnd::DebuggerMainWnd(const char* name) :
     // view menu changes when docking state changes
     connect(dockManager, SIGNAL(change()), SLOT(updateUI()));
 
+    // popup menu of the local variables window
+    m_popupLocals = new QPopupMenu;
+    m_popupLocals->insertItem(i18n("Watch Expression"),
+			      this, SLOT(slotLocalsToWatch()));
+    connect(m_localVariables, SIGNAL(rightPressed(int, const QPoint&)),
+	    this, SLOT(slotLocalsPopup(int, const QPoint&)));
+
     restoreSettings(kapp->getConfig());
 
     connect(m_menuRecentExecutables, SIGNAL(activated(int)), SLOT(slotRecentExec(int)));
@@ -303,6 +310,7 @@ void DebuggerMainWnd::initToolbar()
 			   i18n("Search"));
 
     connect(toolbar, SIGNAL(clicked(int)), SLOT(menuCallback(int)));
+    toolbar->setBarPos(KToolBar::Top);
     
     initAnimation();
 
@@ -820,5 +828,30 @@ QString DebuggerMainWnd::makeSourceFilter()
     return f;
 }
 
+/*
+ * Pop up the context menu in the locals window
+ */
+void DebuggerMainWnd::slotLocalsPopup(int, const QPoint& pt)
+{
+    if (m_popupLocals->isVisible()) {
+	m_popupLocals->hide();
+    } else {
+	m_popupLocals->popup(m_localVariables->mapToGlobal(pt));
+    }
+}
+
+/*
+ * Copies the currently selected item to the watch window.
+ */
+void DebuggerMainWnd::slotLocalsToWatch()
+{
+    int idx = m_localVariables->currentItem();
+
+    if (idx >= 0 && m_debugger != 0) {
+	QString text = m_localVariables->exprStringAt(idx);
+	m_debugger->addWatch(text);
+    }
+}
+
 
 #include "dbgmainwnd.moc"
