@@ -1,4 +1,4 @@
-// $Id: debugger.cpp,v 1.103 2000/11/05 10:02:16 jsixt Exp $
+// $Id: debugger.cpp,v 1.105 2001/06/23 19:24:06 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -1052,22 +1052,23 @@ void KDebugger::updateProgEnvironment(const QString& args, const QString& wd,
     QDictIterator<EnvVar> it = newVars;
     EnvVar* val;
     for (; (val = it) != 0; ++it) {
+	QString var = it.currentKey();
 	switch (val->status) {
 	case EnvVar::EVnew:
-	    m_envVars.insert(it.currentKey(), val);
+	    m_envVars.insert(var, val);
 	    // fall thru
 	case EnvVar::EVdirty:
 	    // the value must be in our list
-	    ASSERT(m_envVars[it.currentKey()] == val);
+	    ASSERT(m_envVars[var] == val);
 	    // update value
-	    m_d->executeCmd(DCsetenv, it.currentKey(), val->value);
+	    m_d->executeCmd(DCsetenv, var, val->value);
 	    break;
 	case EnvVar::EVdeleted:
 	    // must be in our list
-	    ASSERT(m_envVars[it.currentKey()] == val);
+	    ASSERT(m_envVars[var] == val);
 	    // delete value
-	    m_d->executeCmd(DCsetenv, it.currentKey());
-	    m_envVars.remove(it.currentKey());
+	    m_d->executeCmd(DCunsetenv, var);
+	    m_envVars.remove(var);
 	    break;
 	default:
 	    ASSERT(false);
@@ -1799,18 +1800,24 @@ Breakpoint* KDebugger::breakpointByFilePos(QString file, int lineNo,
     // not found, so try basename
     // strip off directory part of file name
     int offset = file.findRev("/");
-    if (offset < 0) {
-	// that was already the basename, no need to scan the list again
-	return 0;
-    }
 #if QT_VERSION < 200
     file.detach();
 #endif
     file.remove(0, offset+1);
 
     for (i = m_brkpts.size()-1; i >= 0; i--) {
+	// get base name of breakpoint's file
+	QString basename = m_brkpts[i]->fileName;
+	int offset = basename.findRev("/");
+	if (offset >= 0) {
+#if QT_VERSION < 200
+	    basename.detach();
+#endif
+	    basename.remove(0, offset+1);
+	}
+
 	if (m_brkpts[i]->lineNo == lineNo &&
-	    m_brkpts[i]->fileName == file &&
+	    basename == file &&
 	    (address.isEmpty() || m_brkpts[i]->address == address))
 	{
 	    return m_brkpts[i];
