@@ -1,4 +1,4 @@
-// $Id: gdbdriver.cpp,v 1.21 2000/08/18 19:22:48 jsixt Exp $
+// $Id: gdbdriver.cpp,v 1.22 2001/01/21 15:36:45 jsixt Exp $
 
 // Copyright by Johannes Sixt
 // This file is under GPL, the GNU General Public Licence
@@ -352,6 +352,23 @@ void GdbDriver::parseMarker()
 }
 
 
+/*
+ * Escapes characters that might lead to problems when they appear on gdb's
+ * command line.
+ */
+static void normalizeStringArg(QString& arg)
+{
+    /*
+     * Remove trailing backslashes. This approach is a little simplistic,
+     * but we know that there is at the moment no case where a trailing
+     * backslash would make sense.
+     */
+    while (!arg.isEmpty() && arg[arg.length()-1] == '\\') {
+	arg = arg.left(arg.length()-1);
+    }
+}
+
+
 #if QT_VERSION < 200
 #define LATIN1(str) ((str).isNull() ? "" : (str).data())
 #else
@@ -363,6 +380,8 @@ QString GdbDriver::makeCmdString(DbgCommand cmd, QString strArg)
     assert(cmd >= 0 && cmd < NUM_CMDS);
     assert(cmds[cmd].argsNeeded == GdbCmdInfo::argString);
 
+    normalizeStringArg(strArg);
+
     if (cmd == DCcd) {
 	// need the working directory when parsing the output
 	m_programWD = strArg;
@@ -398,6 +417,8 @@ QString GdbDriver::makeCmdString(DbgCommand cmd, QString strArg, int intArg)
 	   cmd == DCexamine ||
 	   cmd == DCtty);
 
+    normalizeStringArg(strArg);
+
     SIZED_QString(cmdString, MAX_FMTLEN+30+strArg.length());
 
     if (cmd == DCtty)
@@ -496,6 +517,9 @@ QString GdbDriver::makeCmdString(DbgCommand cmd, QString strArg1, QString strArg
     assert(cmd >= 0 && cmd < NUM_CMDS);
     assert(cmds[cmd].argsNeeded == GdbCmdInfo::argString2);
 
+    normalizeStringArg(strArg1);
+    normalizeStringArg(strArg2);
+
     SIZED_QString(cmdString, MAX_FMTLEN+strArg1.length()+strArg2.length());
     cmdString.sprintf(cmds[cmd].fmt, LATIN1(strArg1), LATIN1(strArg2));
     return cmdString;
